#
# spec file for package python-lfdfiles
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-lfdfiles
Version:        2023.4.20
Release:        1.3
Summary:        Laboratory for Fluorescence Dynamics (LFD) file formats
License:        BSD-3-Clause
URL:            https://www.lfd.uci.edu/~gohlke/
Source:         https://github.com/cgohlke/lfdfiles/archive/v%{version}.tar.gz#/lfdfiles-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module czifile >= 2019.7.2}
BuildRequires:  %{python_module matplotlib >= 3.2.0}
BuildRequires:  %{python_module netpbmfile >= 2020.9.18}
BuildRequires:  %{python_module numpy >= 1.15}
BuildRequires:  %{python_module oiffile >= 2020.9.18}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tifffile >= 2020.9.3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires:       python-czifile >= 2019.7.2
Requires:       python-matplotlib >= 3.2.0
Requires:       python-netpbmfile >= 2020.9.18
Requires:       python-numpy >= 1.15
Requires:       python-oiffile >= 2020.9.18
Requires:       python-tifffile >= 2020.9.3
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
Lfdfiles is a Python library and console script for reading, writing,
converting, and viewing many of the proprietary file formats used to store
experimental data at the Laboratory for Fluorescence Dynamics.

%prep
%setup -q -n lfdfiles-%{version}
# Fix warning: wrong end-of-line encoding
sed -i 's/\r//g' README.rst

%build
%python_build

%install
%python_install
for p in lfdfiles fbd2b64 ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

%python_expand %fdupes %{buildroot}%{$python_sitearch}
%prepare_alternative lfdfiles fbd2b64

%post
%python_install_alternative lfdfiles fbd2b64

%postun
%python_uninstall_alternative lfdfiles fbd2b64

%check
# Test not provided

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/lfdfiles
%python_alternative %{_bindir}/fbd2b64
%{python_sitearch}/*egg-info
%{python_sitearch}/lfdfiles/

%changelog
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.4.20:
  * Improve type hints.
  * Drop support for Python 3.8 and numpy < 1.21 (NEP29).
  * Update metadata.
  * Fix LfdFileSequence with tifffile 2022.4.22.
  * Add fbd2b64 conversion function and script.
  * Add decoder for 32-bit, 8 windows, 4 channels FLIMbox data
    from Spartan-6.
  * Convert docstrings to Google style with Sphinx directives.
  * Add type hints.
  * SimfcsFit.asarray returns dc_ref only; use p_fit for fit
    params (breaking).
  * Remove additional positional arguments to LfdFile init
    (breaking).
  * Guess SimfcsBin shape and dtype if not provided (breaking).
  * Use TiffWriter.write instead of deprecated save.
  * Drop support for Python 3.7 and NumPy < 1.19 (NEP29).
  * Refactor SimfcsFbd initialization.
  * Print tracebacks of failing plugins in LfdFile.
  * Calculate pixel_dwell_time and frame_size for FBD files with
    header.
  * Disable simfcsfbd_decode and simfcsfbd_histogram Python code
    (breaking).
  * Read ISS Vista IFI files.
  * Fix reading FBD files with FBF header.
  * Fix reading R64 files with excess bytes.
  * Fix reading VPL files used by ISS Vista.
  * Remove lazyattr.
  * Fix unclosed file warnings.
  * Replace TIFF compress with compression parameter (breaking).
  * Remove compress option from command line interface
    (breaking).
  * Add function to decode Spectral FLIM data from Kintex
    FLIMbox.
  * Relax VistaIfli file version check.
* Sun Feb 14 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build (no tifffile as it uses scipy)
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 2020.9.18.
  * Remove support for Python 3.6.
  * Support os.PathLike file names.
  * Fix writing contiguous series to TIFF files with
    tifffile >= 2020.9.3.
* Mon Aug 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update the archive to match up the upstream one
* Fri Jul 31 2020 andy great <andythe_great@pm.me>
- Update spec file to use python alternative.
* Mon Jun  1 2020 andy great <andythe_great@pm.me>
- Update to version 2020.1.1.
  * Read CZI files via czifile module.
  * Read Olympus Image files via oiffile module.
  * Read Netpbm formats via netpbmfile module.
  * Add B64, Z64, and I64 write functions.
  * Remove support for Python 2.7 and 3.5.
  * Update copyright.
* Mon Mar  4 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2019.2.20
